#!/usr/bin/env python3

from hero1.hero1 import find_ip, setup, setup_with_ip, init, cmd, render, setCanMoveAll, scan, scanx, testx, moveRight, moveLeft, moveUp, moveDown, canMoveRight, canMoveLeft, canMoveUp, canMoveDown
from hero1.command_pb2 import CmdType, Cmd
from hero1.bodyinfo_pb2 import *
from hero1.pcmd import *

